-- MTZ1221KabSounds.lua
-- Script for Fendt Farmer 310/312 LSA
--
-- Author Rival
-- 05.01.2016
-- Version 1.1 @26.10.2016
	--> converted to FS17
-- Version 1.2 @05.11.2016
	--> added indoorsound change when door/windows are open

MTZ1221KabSounds = {};

function MTZ1221KabSounds.prerequisitesPresent(specializations)
    return true;
end;

function MTZ1221KabSounds:load(savegame)
	
	self.soundAdj = {};
	local i=0;
    while true do
        local key = string.format("vehicle.indoorsoundAdjustment.animation(%d)", i);
        if not hasXMLProperty(self.xmlFile, key) then
            break;
        end;
        local animName = getXMLString(self.xmlFile, key.."#name");
        local lowpassGain = Utils.getNoNil(getXMLFloat(self.xmlFile, key.."#lowpassGain"), 0.5);
        local volumeFactor = Utils.getNoNil(getXMLFloat(self.xmlFile, key.."#volumeFactor"), 0.5);
		self.soundAdj[i] = {};
		self.soundAdj[i].animName = animName;
		self.soundAdj[i].volumeFactor = volumeFactor;
		self.soundAdj[i].lowpassGain = lowpassGain;
        i = i +1;
    end;
	
	if self.isClient then
		self.sampleOpenDoorL = SoundUtil.loadSample(self.xmlFile, {}, "vehicle.openDoorSound", "NewSound/MTZ1221openDoor.wav", self.baseDirectory, self.components[1].node);
		self.sampleCloseDoorL = SoundUtil.loadSample(self.xmlFile, {}, "vehicle.closeDoorSound", "NewSound/MTZ1221closeDoor.wav", self.baseDirectory, self.components[1].node);
		self.sampleOpenDoorR = SoundUtil.loadSample(self.xmlFile, {}, "vehicle.openDoorSound", "NewSound/MTZ1221openDoor.wav", self.baseDirectory, self.components[1].node);
		self.sampleCloseDoorR = SoundUtil.loadSample(self.xmlFile, {}, "vehicle.closeDoorSound", "NewSound/MTZ1221closeDoor.wav", self.baseDirectory, self.components[1].node);
		self.sampleOpenDoorB = SoundUtil.loadSample(self.xmlFile, {}, "vehicle.openDoorSound", "NewSound/MTZ1221open.wav", self.baseDirectory, self.components[1].node);
		self.sampleCloseDoorB = SoundUtil.loadSample(self.xmlFile, {}, "vehicle.closeDoorSound", "NewSound/MTZ1221close.wav", self.baseDirectory, self.components[1].node);
		self.sampleOpenDoorK = SoundUtil.loadSample(self.xmlFile, {}, "vehicle.openDoorSound", "NewSound/KapotOtkr.wav", self.baseDirectory, self.components[1].node);
		self.sampleCloseDoorK = SoundUtil.loadSample(self.xmlFile, {}, "vehicle.closeDoorSound", "NewSound/KapotZakr.wav", self.baseDirectory, self.components[1].node);
		self.sampleOpenDoorKa = SoundUtil.loadSample(self.xmlFile, {}, "vehicle.openDoorSound", "NewSound/MTZ1221open.wav", self.baseDirectory, self.components[1].node);
		self.sampleCloseDoorKa = SoundUtil.loadSample(self.xmlFile, {}, "vehicle.closeDoorSound", "NewSound/MTZ1221close.wav", self.baseDirectory, self.components[1].node);
	end;
end;
--function MTZ1221KabSounds:postLoad(savegame)
--	for k,v in pairs(self.sampleMotor) do print(k,v) end
--end;
function MTZ1221KabSounds:delete()
	if self.sampleOpenDoorL ~= nil then
		SoundUtil.deleteSample(self.sampleOpenDoorL);
	end;
	if self.sampleOpenDoorR ~= nil then
		SoundUtil.deleteSample(self.sampleOpenDoorR);
	end;
	if self.sampleOpenDoorB ~= nil then
		SoundUtil.deleteSample(self.sampleOpenDoorB);
	end;
	if self.sampleOpenDoorK ~= nil then
		SoundUtil.deleteSample(self.sampleOpenDoorK);
	end;
	if self.sampleOpenDoorKa ~= nil then
		SoundUtil.deleteSample(self.sampleOpenDoorKa);
	end;
	if self.sampleCloseDoorL ~= nil then
		SoundUtil.deleteSample(self.sampleCloseDoorL);
	end;
	if self.sampleCloseDoorR ~= nil then
		SoundUtil.deleteSample(self.sampleCloseDoorR);
	end;
	if self.sampleCloseDoorB ~= nil then
		SoundUtil.deleteSample(self.sampleCloseDoorB);
	end;
	if self.sampleCloseDoorK ~= nil then
		SoundUtil.deleteSample(self.sampleCloseDoorK);
	end;
	if self.sampleCloseDoorKa ~= nil then
		SoundUtil.deleteSample(self.sampleCloseDoorKa);
	end;
end;
function MTZ1221KabSounds:mouseEvent(posX, posY, isDown, isUp, button)
end;
function MTZ1221KabSounds:keyEvent(unicode, sym, modifier, isDown)
end;
function MTZ1221KabSounds:update(dt)
    if self:getIsActive() and self.isClient then
		if self.isEntered then
			if self:getIsAnimationPlaying("leftDoor") and self:getIsActiveForSound() then
				if self.animations["leftDoor"].currentSpeed > 0 and self.animations["leftDoor"].currentTime < 50 then
					if not SoundUtil.isSamplePlaying(self.sampleOpenDoorL, 1.5*dt) then
						SoundUtil.playSample(self.sampleOpenDoorL,1,1,nil);
					end;
				elseif self.animations["leftDoor"].currentSpeed < 0 and self.animations["leftDoor"].currentTime < 100 then
					if not SoundUtil.isSamplePlaying(self.sampleCloseDoorL, 1.5*dt) then
						SoundUtil.playSample(self.sampleCloseDoorL,1,1,nil);
					end;
				end;
			end;
			if self:getIsAnimationPlaying("rightDoor") and self:getIsActiveForSound() then
				if self.animations["rightDoor"].currentSpeed > 0 and self.animations["rightDoor"].currentTime < 50 then
					if not SoundUtil.isSamplePlaying(self.sampleOpenDoorR, 1.5*dt) then
						SoundUtil.playSample(self.sampleOpenDoorR,1,1,nil);
					end;
				elseif self.animations["rightDoor"].currentSpeed < 0 and self.animations["rightDoor"].currentTime < 100 then
					if not SoundUtil.isSamplePlaying(self.sampleCloseDoorR, 1.5*dt) then
						SoundUtil.playSample(self.sampleCloseDoorR,1,1,nil);
					end;
				end;
			end;
			if self:getIsAnimationPlaying("backWindow") and self:getIsActiveForSound() then
				if self.animations["backWindow"].currentSpeed > 0 and self.animations["backWindow"].currentTime < 50 then
					if not SoundUtil.isSamplePlaying(self.sampleOpenDoorB, 1.5*dt) then
						SoundUtil.playSample(self.sampleOpenDoorB,1,1,nil);
					end;
				elseif self.animations["backWindow"].currentSpeed < 0 and self.animations["backWindow"].currentTime < 100 then
					if not SoundUtil.isSamplePlaying(self.sampleCloseDoorB, 1.5*dt) then
						SoundUtil.playSample(self.sampleCloseDoorB,1,1,nil);
					end;
				end;
			end;
			if self:getIsAnimationPlaying("Krisha") and self:getIsActiveForSound() then
				if self.animations["Krisha"].currentSpeed > 0 and self.animations["Krisha"].currentTime < 50 then
					if not SoundUtil.isSamplePlaying(self.sampleOpenDoorK, 1.5*dt) then
						SoundUtil.playSample(self.sampleOpenDoorK,1,1,nil);
					end;
				elseif self.animations["Krisha"].currentSpeed < 0 and self.animations["Krisha"].currentTime < 100 then
					if not SoundUtil.isSamplePlaying(self.sampleCloseDoorK, 1.5*dt) then
						SoundUtil.playSample(self.sampleCloseDoorK,1,1,nil);
					end;
				end;
			end;
			if self:getIsAnimationPlaying("Kapot") and self:getIsActiveForSound() then
				if self.animations["Kapot"].currentSpeed > 0 and self.animations["Kapot"].currentTime < 50 then
					if not SoundUtil.isSamplePlaying(self.sampleOpenDoorKa, 1.5*dt) then
						SoundUtil.playSample(self.sampleOpenDoorKa,1,1,nil);
					end;
				elseif self.animations["Kapot"].currentSpeed < 0 and self.animations["Kapot"].currentTime < 100 then
					if not SoundUtil.isSamplePlaying(self.sampleCloseDoorKa, 1.5*dt) then
						SoundUtil.playSample(self.sampleCloseDoorKa,1,1,nil);
					end;
				end;
			end;
			local sound=false;
			for i=0, #self.soundAdj do
				if self.animations[self.soundAdj[i].animName] ~= nil and self.animations[self.soundAdj[i].animName].currentTime > 500 then
					self.sampleMotor.indoorVolumeFactor = math.max(self.soundAdj[i].volumeFactor, self.sampleMotor.indoorVolumeFactor);
					self.sampleMotor.indoorLowpassGain = math.max(self.soundAdj[i].lowpassGain, self.sampleMotor.indoorLowpassGain);
					self.sampleMotorStart.indoorVolumeFactor = math.max(self.soundAdj[i].volumeFactor, self.sampleMotorStart.indoorVolumeFactor);
					self.sampleMotorStart.indoorLowpassGain = math.max(self.soundAdj[i].lowpassGain, self.sampleMotorStart.indoorLowpassGain);
					self.sampleMotorStop.indoorVolumeFactor = math.max(self.soundAdj[i].volumeFactor, self.sampleMotorStop.indoorVolumeFactor);
					self.sampleMotorStop.indoorLowpassGain = math.max(self.soundAdj[i].lowpassGain, self.sampleMotorStop.indoorLowpassGain);
					
					self.sampleMotorRun.indoorVolumeFactor = math.max(self.soundAdj[i].volumeFactor, self.sampleMotorRun.indoorVolumeFactor);
					self.sampleMotorRun.indoorLowpassGain = math.max(self.soundAdj[i].lowpassGain, self.sampleMotorRun.indoorLowpassGain);
					self.sampleMotorLoad.indoorVolumeFactor = math.max(self.soundAdj[i].volumeFactor, self.sampleMotorLoad.indoorVolumeFactor);
					self.sampleMotorLoad.indoorLowpassGain = math.max(self.soundAdj[i].lowpassGain, self.sampleMotorLoad.indoorLowpassGain);
					sound=true;
				else
					if not sound then
						self.sampleMotor.indoorVolumeFactor = 0.55;
						self.sampleMotor.indoorLowpassGain = 0.2;
						self.sampleMotorStart.indoorVolumeFactor = 0.55;
						self.sampleMotorStart.indoorLowpassGain = 0.2;
						self.sampleMotorStop.indoorVolumeFactor = 0.55;
						self.sampleMotorStop.indoorLowpassGain = 0.2;
						
						self.sampleMotorRun.indoorVolumeFactor = 0.6;
						self.sampleMotorRun.indoorLowpassGain = 0.2;
						self.sampleMotorLoad.indoorVolumeFactor = 0.6;
						self.sampleMotorLoad.indoorLowpassGain = 0.2;
					end;
				end;
			end;
			SoundUtil.onCameraSwitched(self.activeCamera.isInside);
		end;
    end;
end;
function MTZ1221KabSounds:updateTick(dt)
end;
function MTZ1221KabSounds:draw()    
end;